@@ -1,9 +1,11 @@
 <?php
-/* view_as_html -- Version 3.3-1.4.x
+/* view_as_html -- Version 3.4-1.4.x
  * By Seth E. Randall <sethr@missoulafcu.org>
  *
  * Code for displaying link only when an HTML part exists
  * Ben Brillat and Pete Walker
+ *
+ * $Id: setup.php,v 1.3 2003/10/15 04:33:30 indiri69 Exp $
  */
     require_once(SM_PATH . 'functions/global.php');
 
@@ -23,4 +25,7 @@
         view_as_html_link();
     }
 
+    function view_as_html_version() {
+        return '3.4-1.4.x';
+    }
 ?>
